@@ -1,7 +1,7 @@
 """Main API for Rite Aid."""
 import aiohttp
 import json
-import asyncio
+from urllib.parse import quote
 
 from .const import GET_STORES_URL, REFILL_RX_URL
 from .exceptions import RiteAidError
@@ -24,16 +24,13 @@ class RiteAidAPI:
     async def refill_rx(prescription_nums, store_id, date, time, phone):
         """Refill a prescription."""
         # Using application/x-www-form-urlencoded
-        form = aiohttp.FormData()
-        data = {
-            "refillPrescriptions": json.dumps(prescription_nums),
-            "location": store_id,
-            "pickUpDate": date,
-            "pickUpTime": time,
-            "phoneNumber": phone
-        }
-        for key, value in data.items():
-            form.add_field(key, value)
+        form = quote("refillPrescriptions={}&location={}&pickUpDate={}&pickUpTime={}&phone={}".format(
+            json.dumps(prescription_nums),
+            store_id,
+            date,
+            time,
+            phone
+        ))
         async with aiohttp.ClientSession() as session:
             async with session.post(REFILL_RX_URL, data=form) as resp:
                 return await resp.json()
\ No newline at end of file
